@@ -72,9 +72,9 @@ module Net; module SSH
       # ones. Returns a hash containing the OpenSSH options. (See
       # #translate for how to convert the OpenSSH options into Net::SSH
       # options.)
-      def load(path, host, settings={})
+      def load(path, host, settings={}, base_dir = nil)
         file = File.expand_path(path)
-        base_dir = File.dirname(file)
+        base_dir ||= File.dirname(file)
         return settings unless File.readable?(file)
 
         globals = {}
@@ -125,7 +125,7 @@ module Net; module SSH
               (globals[key] ||= []) << value
             when 'include'
               included_file_paths(base_dir, value).each do |file_path|
-                globals = load(file_path, host, globals)
+                globals = load(file_path, host, globals, base_dir)
               end
             else
               globals[key] = value unless settings.key?(key)
@@ -136,7 +136,7 @@ module Net; module SSH
               (settings[key] ||= []) << value
             when 'include'
               included_file_paths(base_dir, value).each do |file_path|
-                settings = load(file_path, host, settings)
+                settings = load(file_path, host, settings, base_dir)
               end
             else
               settings[key] = value unless settings.key?(key)
@@ -144,7 +144,16 @@ module Net; module SSH
           end
         end
 
-        settings = globals.merge(settings) if globals
+        if globals
+          settings = globals.merge(settings) do |key, oldval, newval|
+            case key
+            when 'identityfile'
+              oldval + newval
+            else
+              newval
+            end
+          end
+        end
 
         return settings
       end
@@ -303,12 +312,17 @@ module Net; module SSH
           hash
         end
 
-        def included_file_paths(base_dir, config_path)
-          paths = Dir.glob(File.expand_path(config_path)).select { |f| File.file?(f) }
-          paths += Dir.glob(File.join(base_dir, config_path)).select { |f| File.file?(f) }
-          paths.uniq
+        def included_file_paths(base_dir, config_paths)
+          tokenize_config_value(config_paths).flat_map do |path|
+            Dir.glob(File.expand_path(path, base_dir)).select { |f| File.file?(f) }
+          end
         end
 
+        # Tokenize string into tokens.
+        # A token is a word or a quoted sequence of words, separated by whitespaces.
+        def tokenize_config_value(str)
+          str.scan(/([^"\s]+)?(?:"([^"]+)")?\s*/).map(&:join)
+        end
     end
   end
 
