@@ -57,7 +57,8 @@ module Net; module SSH; module Proxy
       begin
         io = IO.popen(command_line, "r+")
         if result = Net::SSH::Compat.io_select([io], nil, [io], 60)
-          if result.last.any?
+          if result.last.any? || io.eof?
+            io.close
             raise "command failed"
           end
         else
@@ -79,11 +80,26 @@ module Net; module SSH; module Proxy
         end
       else
         def io.send(data, flag)
-          write_nonblock(data)
+          begin
+            result = write_nonblock(data)
+          rescue IO::WaitWritable, Errno::EINTR
+            IO.select(nil, [self])
+            retry
+          end
+          result
         end
 
         def io.recv(size)
-          read_nonblock(size)
+          begin
+            result = read_nonblock(size)
+          rescue IO::WaitReadable, Errno::EINTR
+            timeout_in_seconds = 20
+            if IO.select([self], nil, [self], timeout_in_seconds) == nil
+              raise "Unexpected spurious read wakeup"
+            end
+            retry
+          end
+          result
         end
       end
       io
