@@ -6,16 +6,16 @@ module Authentication; module Methods
     private
 
       def socket(options={})
-        @socket ||= stub("socket", :client_name => "me.ssh.test")
+        @socket ||= stub("socket", client_name: "me.ssh.test")
       end
 
       def transport(options={})
-        @transport ||= MockTransport.new(options.merge(:socket => socket))
+        @transport ||= MockTransport.new(options.merge(socket: socket))
       end
 
       def session(options={})
         @session ||= begin
-          sess = stub("auth-session", :logger => nil, :transport => transport(options))
+          sess = stub("auth-session", logger: nil, transport: transport(options))
           def sess.next_message
             transport.next_message
           end
@@ -23,6 +23,12 @@ module Authentication; module Methods
         end
       end
 
+      def reset_session(options = {})
+        @transport = nil
+        @session = nil
+        session(options)
+      end
+
   end
 
 end; end
\ No newline at end of file
