@@ -1,9 +1,9 @@
-require 'common'
+require_relative '../common'
 require 'net/ssh/authentication/key_manager'
 
 module Authentication
 
-  class TestKeyManager < Test::Unit::TestCase
+  class TestKeyManager < NetSSHTest
     def test_key_files_and_known_identities_are_empty_by_default
       assert manager.key_files.empty?
       assert manager.known_identities.empty?
@@ -35,7 +35,7 @@ module Authentication
     end
 
     def test_agent_should_not_be_used_with_no_agent
-      assert !manager(:use_agent => false).use_agent?
+      assert !manager(use_agent: false).use_agent?
     end
 
     def test_each_identity_should_load_from_key_files
@@ -52,14 +52,27 @@ module Authentication
       assert_equal rsa.to_blob, identities.first.to_blob
       assert_equal dsa.to_blob, identities.last.to_blob
 
-      assert_equal({:from => :file, :file => first, :key => rsa}, manager.known_identities[rsa])
-      assert_equal({:from => :file, :file => second, :key => dsa}, manager.known_identities[dsa])
+      assert_equal({from: :file, file: first, key: rsa}, manager.known_identities[rsa])
+      assert_equal({from: :file, file: second, key: dsa}, manager.known_identities[dsa])
+    end
+
+    def test_each_identity_should_load_form_cert_file
+      manager.stubs(:agent).returns(nil)
+      first = File.expand_path("/first")
+      stub_file_cert first, rsa
+
+      identities = []
+      manager.each_identity { |identity| identities << identity }
+
+      assert_equal 1, identities.length
+      assert_equal rsa.to_blob, identities.first.to_blob
+      assert_equal({from: :file, file: first}, manager.known_identities[rsa])
     end
 
     def test_each_identity_should_not_prompt_for_passphrase_in_non_interactive_mode
-      manager(:non_interactive => true).stubs(:agent).returns(nil)
+      manager(non_interactive: true).stubs(:agent).returns(nil)
       first = File.expand_path("/first")
-      stub_file_private_key first, rsa, :passphrase => :should_not_be_asked
+      stub_file_private_key first, rsa, passphrase: :should_not_be_asked
       identities = []
       manager.each_identity { |identity| identities << identity }
       assert_equal(identities, [])
@@ -75,8 +88,8 @@ module Authentication
       assert_equal rsa.to_blob, identities.first.to_blob
       assert_equal dsa.to_blob, identities.last.to_blob
 
-      assert_equal({:from => :agent}, manager.known_identities[rsa])
-      assert_equal({:from => :agent}, manager.known_identities[dsa])
+      assert_equal({from: :agent}, manager.known_identities[rsa])
+      assert_equal({from: :agent}, manager.known_identities[dsa])
     end
 
     if defined?(OpenSSL::PKey::EC)
@@ -93,16 +106,16 @@ module Authentication
         assert_equal ecdsa_sha2_nistp384.to_blob, identities[3].to_blob
         assert_equal ecdsa_sha2_nistp521.to_blob, identities[4].to_blob
 
-        assert_equal({:from => :agent}, manager.known_identities[rsa])
-        assert_equal({:from => :agent}, manager.known_identities[dsa])
-        assert_equal({:from => :agent}, manager.known_identities[ecdsa_sha2_nistp256])
-        assert_equal({:from => :agent}, manager.known_identities[ecdsa_sha2_nistp384])
-        assert_equal({:from => :agent}, manager.known_identities[ecdsa_sha2_nistp521])
+        assert_equal({from: :agent}, manager.known_identities[rsa])
+        assert_equal({from: :agent}, manager.known_identities[dsa])
+        assert_equal({from: :agent}, manager.known_identities[ecdsa_sha2_nistp256])
+        assert_equal({from: :agent}, manager.known_identities[ecdsa_sha2_nistp384])
+        assert_equal({from: :agent}, manager.known_identities[ecdsa_sha2_nistp521])
       end
     end
 
     def test_only_identities_with_key_files_should_load_from_agent_of_keys_only_set
-      manager(:keys_only => true).stubs(:agent).returns(agent)
+      manager(keys_only: true).stubs(:agent).returns(agent)
 
       first = File.expand_path("/first")
       stub_file_private_key first, rsa
@@ -113,7 +126,7 @@ module Authentication
       assert_equal 1, identities.length
       assert_equal rsa.to_blob, identities.first.to_blob
 
-      assert_equal({:from => :agent}, manager.known_identities[rsa])
+      assert_equal({from: :agent}, manager.known_identities[rsa])
       assert manager.use_agent?
     end
 
@@ -123,7 +136,7 @@ module Authentication
       first = File.expand_path("/first")
       stub_file_public_key  first, rsa
       second = File.expand_path("/second")
-      stub_file_private_key second, dsa, :passphrase => :should_not_be_asked
+      stub_file_private_key second, dsa, passphrase: :should_not_be_asked
 
       identities = []
       manager.each_identity do |identity|
@@ -152,7 +165,7 @@ module Authentication
     end
 
     def test_sign_with_file_originated_key_should_raise_key_manager_error_if_unloadable
-      manager.known_identities[rsa] = { :from => :file, :file => "/first" }
+      manager.known_identities[rsa] = { from: :file, file: "/first" }
 
       Net::SSH::KeyFactory.expects(:load_private_key).raises(OpenSSL::PKey::RSAError)
 
@@ -169,16 +182,17 @@ module Authentication
         File.stubs(:readable?).with(name).returns(true)
         File.stubs(:file?).with(name + ".pub").returns(true)
         File.stubs(:readable?).with(name + ".pub").returns(false)
+        File.stubs(:file?).with(name + "-cert.pub").returns(false)
 
         case options.fetch(:passphrase, :indifferently)
         when :should_be_asked
-          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, false).raises(OpenSSL::PKey::RSAError).at_least_once
-          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, true).returns(key).at_least_once
+          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, false, prompt).raises(OpenSSL::PKey::RSAError).at_least_once
+          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, true, prompt).returns(key).at_least_once
         when :should_not_be_asked
-          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, false).raises(OpenSSL::PKey::RSAError).at_least_once
-          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, true).never
+          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, false, prompt).raises(OpenSSL::PKey::RSAError).at_least_once
+          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, true, prompt).never
         else # :indifferently
-          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, any_of(true, false)).returns(key).at_least_once
+          Net::SSH::KeyFactory.expects(:load_private_key).with(name, nil, any_of(true, false), prompt).returns(key).at_least_once
         end
 
         # do not override OpenSSL::PKey::EC#public_key
@@ -194,10 +208,23 @@ module Authentication
         File.stubs(:readable?).with(name).returns(true)
         File.stubs(:file?).with(name + ".pub").returns(true)
         File.stubs(:readable?).with(name + ".pub").returns(true)
+        File.stubs(:file?).with(name + "-cert.pub").returns(false)
 
         Net::SSH::KeyFactory.expects(:load_public_key).with(name + ".pub").returns(key).at_least_once
       end
 
+      def stub_file_cert(name, key)
+        manager.add(name)
+        File.stubs(:file?).with(name).returns(true)
+        File.stubs(:readable?).with(name).returns(true)
+        File.stubs(:file?).with(name + ".pub").returns(true)
+        File.stubs(:readable?).with(name + ".pub").returns(true)
+        File.stubs(:file?).with(name + "-cert.pub").returns(true)
+        File.stubs(:readable?).with(name + "-cert.pub").returns(true)
+
+        Net::SSH::KeyFactory.expects(:load_public_key).with(name + "-cert.pub").returns(key).at_least_once
+      end
+
       def rsa(size=512)
         @rsa ||= OpenSSL::PKey::RSA.new(size)
       end
@@ -221,18 +248,22 @@ module Authentication
       end
 
       def agent
-        @agent ||= stub("agent", :identities => [rsa, dsa])
+        @agent ||= stub("agent", identities: [rsa, dsa])
       end
 
       def agent_with_ecdsa_keys
-        @agent ||= stub("agent", :identities => [rsa, dsa,
-                                                 ecdsa_sha2_nistp256,
-                                                 ecdsa_sha2_nistp384,
-                                                 ecdsa_sha2_nistp521])
+        @agent ||= stub("agent", identities: [rsa, dsa,
+                                              ecdsa_sha2_nistp256,
+                                              ecdsa_sha2_nistp384,
+                                              ecdsa_sha2_nistp521])
+      end
+
+      def prompt
+        @promp ||= MockPrompt.new
       end
 
       def manager(options = {})
-        @manager ||= Net::SSH::Authentication::KeyManager.new(nil, options)
+        @manager ||= Net::SSH::Authentication::KeyManager.new(nil, {password_prompt: prompt}.merge(options))
       end
 
   end
