@@ -1,7 +1,16 @@
 $LOAD_PATH.unshift "#{File.dirname(__FILE__)}/../lib"
-gem "test-unit" # http://rubyforge.org/pipermail/test-unit-tracker/2009-July/000075.html
-gem 'mocha'
-require 'test/unit'
+
+if ENV["CI"]
+  unless Gem.win_platform?
+    require 'simplecov'
+    SimpleCov.start
+
+    require 'codecov'
+    SimpleCov.formatter = SimpleCov::Formatter::Codecov
+  end
+end
+
+require 'minitest'
 require 'mocha/setup'
 require 'net/ssh/buffer'
 require 'net/ssh/config'
@@ -10,9 +19,11 @@ require 'net/ssh/packet'
 require 'net/ssh/transport/session'
 require 'ostruct'
 
+require 'minitest/autorun'
+
 # clear the default files out so that tests don't get confused by existing
 # SSH config files.
-$original_config_default_files = Net::SSH::Config.default_files.dup
+$_original_config_default_files = Net::SSH::Config.default_files.dup # rubocop:disable Style/GlobalVars
 Net::SSH::Config.default_files.clear
 
 def with_restored_default_files(&block)
@@ -31,6 +42,29 @@ def P(*args)
   Net::SSH::Packet.new(Net::SSH::Buffer.from(*args))
 end
 
+class NetSSHTest < Minitest::Test
+  def assert_nothing_raised(&block)
+    yield
+  end
+
+  def assert_not_nil obj, msg = nil
+    refute_nil obj, msg
+  end
+end
+
+class MockPrompt
+  def start(info)
+    @info = info
+    self
+  end
+
+  def ask(message, echo)
+    _ask(message, @info, echo)
+  end
+
+  def success; end
+end
+
 class MockTransport < Net::SSH::Transport::Session
   class BlockVerifier
     def initialize(block)
@@ -56,12 +90,12 @@ class MockTransport < Net::SSH::Transport::Session
     @options = options
     self.logger = options[:logger]
     self.host_as_string = "net.ssh.test,127.0.0.1"
-    self.server_version = OpenStruct.new(:version => "SSH-2.0-Ruby/Net::SSH::Test")
+    self.server_version = OpenStruct.new(version: "SSH-2.0-Ruby/Net::SSH::Test")
     @expectation = nil
     @queue = []
     @hints = {}
     @socket = options[:socket]
-    @algorithms = OpenStruct.new(:session_id => "abcxyz123")
+    @algorithms = OpenStruct.new(session_id: "abcxyz123")
     verifier { |data| true }
   end
 
