@@ -1,9 +1,9 @@
 # encoding: ASCII-8BIT
 
-require 'common'
+require_relative 'common'
 require 'net/ssh/buffer'
 
-class TestBuffer < Test::Unit::TestCase
+class TestBuffer < NetSSHTest
   def test_constructor_should_initialize_buffer_to_empty_by_default
     buffer = new
     assert buffer.empty?
@@ -26,6 +26,34 @@ class TestBuffer < Test::Unit::TestCase
     assert_equal "\1\0\0\0\2\0\0\0\0\0\0\0\3\0\0\0\0014\1\0\000\000\000\004I\226\002\322something", buffer.to_s
   end
 
+  def test_from_should_build_new_buffer_that_includes_utf8_string_128_characters
+    length = 128
+    # letter A has a 1 byte UTF8 representation
+    buffer = Net::SSH::Buffer.from(:long, 2, :string, 'A' * length)
+    # long of 2 + length 128 as network endian + 128 A's
+    expected = "\x00\x00\x00\x02" + [length].pack('N*') + ("\x41" * length)
+    assert_equal expected, buffer.to_s
+  end
+
+  def test_from_should_build_new_buffer_with_frozen_strings
+    foo = 'foo'.freeze
+    buffer = Net::SSH::Buffer.from(:string, foo)
+    assert_equal "\0\0\0\3foo", buffer.to_s
+  end
+
+  def test_from_should_build_new_buffer_with_utf8_frozen_strings
+    foo = "\u2603".freeze
+    buffer = Net::SSH::Buffer.from(:string, foo)
+    assert_equal "\0\0\0\3\u2603".force_encoding('BINARY'), buffer.to_s
+  end
+
+  def test_from_should_not_change_regular_paramaters
+    foo = "\u2603"
+    buffer = Net::SSH::Buffer.from(:string, foo)
+    assert_equal "\0\0\0\3\u2603".force_encoding('BINARY'), buffer.to_s
+    assert_equal foo.encoding.to_s, "UTF-8"
+  end
+
   def test_from_with_array_argument_should_write_multiple_of_the_given_type
     buffer = Net::SSH::Buffer.from(:byte, [1,2,3,4,5])
     assert_equal "\1\2\3\4\5", buffer.to_s
@@ -33,7 +61,7 @@ class TestBuffer < Test::Unit::TestCase
 
   def test_from_should_measure_bytesize_of_utf_8_string_correctly
     buffer = Net::SSH::Buffer.from(:string, "\u2603") # Snowman is 3 bytes
-    assert_equal "\0\0\0\3\u2603", buffer.to_s
+    assert_equal "\0\0\0\3\u2603".force_encoding('BINARY'), buffer.to_s
   end
 
   def test_read_without_argument_should_read_to_end
@@ -291,10 +319,15 @@ class TestBuffer < Test::Unit::TestCase
     buffer = new("start")
 
     key = OpenSSL::PKey::DSA.new
-    key.p = 0xffeeddccbbaa9988
-    key.q = 0x7766554433221100
-    key.g = 0xffddbb9977553311
-    key.pub_key = 0xeeccaa8866442200
+    if key.respond_to?(:set_pqg)
+      key.set_pqg(0xffeeddccbbaa9988, 0x7766554433221100, 0xffddbb9977553311)
+      key.set_key(0xeeccaa8866442200, nil)
+    else
+      key.p = 0xffeeddccbbaa9988
+      key.q = 0x7766554433221100
+      key.g = 0xffddbb9977553311
+      key.pub_key = 0xeeccaa8866442200
+    end
 
     buffer.write_key(key)
 assert_equal "start\0\0\0\7ssh-dss\0\0\0\011\0\xff\xee\xdd\xcc\xbb\xaa\x99\x88\0\0\0\010\x77\x66\x55\x44\x33\x22\x11\x00\0\0\0\011\0\xff\xdd\xbb\x99\x77\x55\x33\x11\0\0\0\011\0\xee\xcc\xaa\x88\x66\x44\x22\x00", buffer.to_s
@@ -304,8 +337,12 @@ assert_equal "start\0\0\0\7ssh-dss\0\0\0\011\0\xff\xee\xdd\xcc\xbb\xaa\x99\x88\0
     buffer = new("start")
 
     key = OpenSSL::PKey::RSA.new
-    key.e = 0xffeeddccbbaa9988
-    key.n = 0x7766554433221100
+    if key.respond_to?(:set_key)
+      key.set_key(0x7766554433221100, 0xffeeddccbbaa9988, nil)
+    else
+      key.e = 0xffeeddccbbaa9988
+      key.n = 0x7766554433221100
+    end
 
     buffer.write_key(key)
     assert_equal "start\0\0\0\7ssh-rsa\0\0\0\011\0\xff\xee\xdd\xcc\xbb\xaa\x99\x88\0\0\0\010\x77\x66\x55\x44\x33\x22\x11\x00", buffer.to_s
