@@ -1,11 +1,11 @@
-require 'common'
+require_relative 'common'
 require 'net/ssh/key_factory'
 
-class TestKeyFactory < Test::Unit::TestCase
+class TestKeyFactory < NetSSHTest
   def setup
     @key_file = File.expand_path("/key-file")
   end
-  
+
   def test_load_unencrypted_private_RSA_key_should_return_key
     File.expects(:read).with(@key_file).returns(rsa_key.export)
     assert_equal rsa_key.to_der, Net::SSH::KeyFactory.load_private_key(@key_file).to_der
@@ -17,9 +17,10 @@ class TestKeyFactory < Test::Unit::TestCase
   end
 
   def test_load_encrypted_private_RSA_key_should_prompt_for_password_and_return_key
+    prompt = MockPrompt.new
     File.expects(:read).with(@key_file).returns(encrypted(rsa_key, "password"))
-    Net::SSH::KeyFactory.expects(:prompt).with("Enter passphrase for #{@key_file}:", false).returns("password")
-    assert_equal rsa_key.to_der, Net::SSH::KeyFactory.load_private_key(@key_file).to_der
+    prompt.expects(:_ask).with("Enter passphrase for #{@key_file}:", has_entries(type: 'private_key', filename: @key_file), false).returns("password")
+    assert_equal rsa_key.to_der, Net::SSH::KeyFactory.load_private_key(@key_file, nil, true, prompt).to_der
   end
 
   def test_load_encrypted_private_RSA_key_with_password_should_not_prompt_and_return_key
@@ -28,9 +29,12 @@ class TestKeyFactory < Test::Unit::TestCase
   end
 
   def test_load_encrypted_private_DSA_key_should_prompt_for_password_and_return_key
-    File.expects(:read).with(@key_file).returns(encrypted(dsa_key, "password"))
-    Net::SSH::KeyFactory.expects(:prompt).with("Enter passphrase for #{@key_file}:", false).returns("password")
-    assert_equal dsa_key.to_der, Net::SSH::KeyFactory.load_private_key(@key_file).to_der
+    prompt = MockPrompt.new
+    data = encrypted(dsa_key, "password")
+    File.expects(:read).with(@key_file).returns(data)
+    sha = Digest::SHA256.digest(data)
+    prompt.expects(:_ask).with("Enter passphrase for #{@key_file}:", {type: 'private_key', filename: @key_file, sha: sha}, false).returns("password")
+    assert_equal dsa_key.to_der, Net::SSH::KeyFactory.load_private_key(@key_file, nil, true, prompt).to_der
   end
 
   def test_load_encrypted_private_DSA_key_with_password_should_not_prompt_and_return_key
@@ -39,25 +43,26 @@ class TestKeyFactory < Test::Unit::TestCase
   end
 
   def test_load_encrypted_private_key_should_give_three_tries_for_the_password_and_then_raise_exception
+    prompt = MockPrompt.new
     File.expects(:read).with(@key_file).returns(encrypted(rsa_key, "password"))
-    Net::SSH::KeyFactory.expects(:prompt).times(3).with("Enter passphrase for #{@key_file}:", false).returns("passwod","passphrase","passwd")
+    prompt.expects(:_ask).times(3).with("Enter passphrase for #{@key_file}:", has_entries(type: 'private_key', filename: @key_file), false).returns("passwod","passphrase","passwd")
     if OpenSSL::PKey.respond_to?(:read)
-      error_class = ArgumentError
+      error_class = [ArgumentError, OpenSSL::PKey::PKeyError]
     else
-      error_class = OpenSSL::PKey::RSAError
+      error_class = [OpenSSL::PKey::RSAError]
     end
-    assert_raises(error_class) { Net::SSH::KeyFactory.load_private_key(@key_file) }
+    assert_raises(*error_class) { Net::SSH::KeyFactory.load_private_key(@key_file, nil, true, prompt) }
   end
 
   def test_load_encrypted_private_key_should_raise_exception_without_asking_passphrase
     File.expects(:read).with(@key_file).returns(encrypted(rsa_key, "password"))
     Net::SSH::KeyFactory.expects(:prompt).never
     if OpenSSL::PKey.respond_to?(:read)
-      error_class = ArgumentError
+      error_class = [ArgumentError, OpenSSL::PKey::PKeyError]
     else
-      error_class = OpenSSL::PKey::RSAError
+      error_class = [OpenSSL::PKey::RSAError]
     end
-    assert_raises(error_class) { Net::SSH::KeyFactory.load_private_key(@key_file, nil, false) }
+    assert_raises(*error_class) { Net::SSH::KeyFactory.load_private_key(@key_file, nil, false) }
   end
 
   def test_load_public_rsa_key_should_return_key
@@ -65,30 +70,44 @@ class TestKeyFactory < Test::Unit::TestCase
     assert_equal rsa_key.to_blob, Net::SSH::KeyFactory.load_public_key(@key_file).to_blob
   end
 
+  def test_load_public_rsa_key_with_comment_should_return_key
+    File.expects(:read).with(@key_file).returns(public(rsa_key) + " key_comment")
+    assert_equal rsa_key.to_blob, Net::SSH::KeyFactory.load_public_key(@key_file).to_blob
+  end
+
+  def test_load_public_rsa_key_with_options_should_return_key
+    File.expects(:read).with(@key_file).returns(public(rsa_key, 'environment="FOO=bar"'))
+    assert_equal rsa_key.to_blob, Net::SSH::KeyFactory.load_public_key(@key_file).to_blob
+  end
+
+  def test_load_public_rsa_key_with_options_and_comment_should_return_key
+    File.expects(:read).with(@key_file).returns(public(rsa_key, 'environment="FOO=bar"')  + " key_comment")
+    assert_equal rsa_key.to_blob, Net::SSH::KeyFactory.load_public_key(@key_file).to_blob
+  end
   if defined?(OpenSSL::PKey::EC)
     def test_load_unencrypted_private_ecdsa_sha2_nistp256_key_should_return_key
-      File.expects(:read).with("/key-file").returns(ecdsa_sha2_nistp256_key.to_pem)
+      File.expects(:read).with(@key_file).returns(ecdsa_sha2_nistp256_key.to_pem)
       assert_equal ecdsa_sha2_nistp256_key.to_der, Net::SSH::KeyFactory.load_private_key("/key-file").to_der
     end
     def test_load_unencrypted_private_ecdsa_sha2_nistp384_key_should_return_key
-      File.expects(:read).with("/key-file").returns(ecdsa_sha2_nistp384_key.to_pem)
+      File.expects(:read).with(@key_file).returns(ecdsa_sha2_nistp384_key.to_pem)
       assert_equal ecdsa_sha2_nistp384_key.to_der, Net::SSH::KeyFactory.load_private_key("/key-file").to_der
     end
     def test_load_unencrypted_private_ecdsa_sha2_nistp521_key_should_return_key
-      File.expects(:read).with("/key-file").returns(ecdsa_sha2_nistp521_key.to_pem)
+      File.expects(:read).with(@key_file).returns(ecdsa_sha2_nistp521_key.to_pem)
       assert_equal ecdsa_sha2_nistp521_key.to_der, Net::SSH::KeyFactory.load_private_key("/key-file").to_der
     end
 
     def test_load_public_ecdsa_sha2_nistp256_key_should_return_key
-      File.expects(:read).with("/key-file").returns(public(ecdsa_sha2_nistp256_key))
+      File.expects(:read).with(@key_file).returns(public(ecdsa_sha2_nistp256_key))
       assert_equal ecdsa_sha2_nistp256_key.to_blob, Net::SSH::KeyFactory.load_public_key("/key-file").to_blob
     end
     def test_load_public_ecdsa_sha2_nistp384_key_should_return_key
-      File.expects(:read).with("/key-file").returns(public(ecdsa_sha2_nistp384_key))
+      File.expects(:read).with(@key_file).returns(public(ecdsa_sha2_nistp384_key))
       assert_equal ecdsa_sha2_nistp384_key.to_blob, Net::SSH::KeyFactory.load_public_key("/key-file").to_blob
     end
     def test_load_public_ecdsa_sha2_nistp521_key_should_return_key
-      File.expects(:read).with("/key-file").returns(public(ecdsa_sha2_nistp521_key))
+      File.expects(:read).with(@key_file).returns(public(ecdsa_sha2_nistp521_key))
       assert_equal ecdsa_sha2_nistp521_key.to_blob, Net::SSH::KeyFactory.load_public_key("/key-file").to_blob
     end
   end
@@ -162,11 +181,16 @@ WEKt5v3QsUEgVrzkM4K9UbI=
     end
 
     def encrypted(key, password)
-      key.export(OpenSSL::Cipher::Cipher.new("des-ede3-cbc"), password)
+      cipher = OpenSSL::Cipher.new("des-ede3-cbc")
+      key.export(cipher, password)
     end
 
-    def public(key)
-      result = "#{key.ssh_type} "
+    def public(key, args = nil)
+      result = ""
+      if !args.nil?
+        result << "#{args} "
+      end
+      result << "#{key.ssh_type} "
       result << [Net::SSH::Buffer.from(:key, key).to_s].pack("m*").strip.tr("\n\r\t ", "")
       result << " joe@host.test"
     end
