@@ -3,7 +3,7 @@ require 'net/ssh/transport/identity_cipher'
 
 module Transport
 
-  class TestIdentityCipher < Test::Unit::TestCase
+  class TestIdentityCipher < NetSSHTest
 
     def test_block_size_should_be_8
       assert_equal 8, cipher.block_size
